@@ -1,17 +1,18 @@
 
 """Ledger Nano Bitcoin app client"""
 
-from .client_base import Client, TransportClient
+from .client_base import Client, TransportClient, PartialSignature
 from .client import createClient
 from .common import Chain
 
 from .wallet import AddressType, WalletPolicy, MultisigWallet, WalletType
 
-__version__ = '0.1.1'
+__version__ = '0.2.0'
 
 __all__ = [
     "Client",
     "TransportClient",
+    "PartialSignature",
     "createClient",
     "Chain",
     "AddressType",
